# rust_nurbs
Welcome to **rust_nurbs**, a Python API for evaluation of Non-Uniform Rational B-Splines (NURBS) curves and surfaces implemented in Rust. The primary goals of this package are to allow for extremely fast NURBS evaluation while providing a user-friendly interface through Python with zero external dependencies.

- Install this package from PyPi using `pip install rust_nurbs` or `pip install rust-nurbs`
- Check out the documentation page [here](https://rust-nurbs.readthedocs.io/en/latest/)
